==> haskell-socks-0.5.6-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.5.6
id: socks-0.5.6-G2vRSeTs4u6B7ys2Ppk1gS
key: socks-0.5.6-G2vRSeTs4u6B7ys2Ppk1gS
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: 06914643bb6c54235c7365ea289e79ff
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.6.4/site-local/socks-0.5.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/socks-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/socks-0.5.6
hs-libraries: HSsocks-0.5.6-G2vRSeTs4u6B7ys2Ppk1gS
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    network-2.8.0.0-65TWeU8omLsDYfm0yvOQxG
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-socks-0.5.6-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.5.6
id: socks-0.5.6-A0XRMnVg0UJ7fsoDMCw7tg
key: socks-0.5.6-A0XRMnVg0UJ7fsoDMCw7tg
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: b725f8ed427fec70cd8bb6d0d5d775eb
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.6.4/site-local/socks-0.5.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/socks-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/socks-0.5.6
hs-libraries: HSsocks-0.5.6-A0XRMnVg0UJ7fsoDMCw7tg
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    network-2.8.0.0-79Coriq35AYDs1MobOTL51
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
